@@ -3,25 +3,31 @@ from timeit import default_timer as timer
 import torch
 import numpy as np
 from all.core import State
-from .writer import ExperimentWriter
+from .writer import ExperimentWriter, CometWriter
 from .experiment import Experiment
 
+
 class ParallelEnvExperiment(Experiment):
     '''An Experiment object for training and testing agents that use parallel training environments.'''
+
     def __init__(
             self,
-            agent,
+            preset,
             env,
+            name=None,
+            train_steps=float('inf'),
             logdir='runs',
             quiet=False,
             render=False,
-            write_loss=True
+            write_loss=True,
+            writer="tensorboard"
     ):
-        super().__init__(self._make_writer(logdir, agent[0].__name__, env.name, write_loss), quiet)
-        make_agent, n_envs = agent
-        self._envs = env.duplicate(n_envs)
-        self._agent = make_agent(self._envs, self._writer)
-        self._n_envs = n_envs
+        self._name = name if name is not None else preset.name
+        super().__init__(self._make_writer(logdir, self._name, env.name, write_loss, writer), quiet)
+        self._n_envs = preset.n_envs
+        self._envs = env.duplicate(self._n_envs)
+        self._preset = preset
+        self._agent = preset.agent(writer=self._writer, train_steps=train_steps)
         self._render = render
 
         # training state
@@ -55,11 +61,15 @@ class ParallelEnvExperiment(Experiment):
             self._step()
 
     def test(self, episodes=100):
-        self._test_reset(episodes)
-        while len(self._test_returns) < episodes:
-            self._test_step()
-        self._log_test(self._test_returns)
-        return self._test_returns
+        test_agent = self._preset.test_agent()
+        env = self._envs[0].duplicate(1)[0]
+        returns = []
+        for episode in range(episodes):
+            episode_return = self._run_test_episode(test_agent, env)
+            returns.append(episode_return)
+            self._log_test_episode(episode, episode_return)
+        self._log_test(returns)
+        return returns
 
     def _reset(self):
         for env in self._envs:
@@ -99,39 +109,6 @@ class ParallelEnvExperiment(Experiment):
                     env.step(action)
                     self._frame += 1
 
-    def _test_reset(self, episodes):
-        self._reset()
-        self._test_episodes = episodes
-        self._test_episodes_started = 0
-        self._test_returns = []
-        self._should_save_returns = [True] * self._n_envs
-
-    def _test_step(self):
-        states = self._aggregate_states()
-        actions = self._agent.eval(states)
-        self._test_step_envs(actions)
-
-    def _test_step_envs(self, actions):
-        for i, env in enumerate(self._envs):
-            state = env.state
-            if self._render:
-                env.render()
-            if state.done:
-                self._returns[i] += state.reward
-                if self._should_save_returns[i]:
-                    self._test_returns.append(self._returns[i].item())
-                    self._log_test_episode(len(self._test_returns), self._returns[i].item())
-                if self._test_episodes_started > self._test_episodes:
-                    self._should_save_returns[i] = False
-                env.reset()
-                self._returns[i] = 0
-                self._test_episodes_started += 1
-            else:
-                action = actions[i]
-                if action is not None:
-                    self._returns[i] += state.reward
-                    env.step(action)
-
     def _aggregate_states(self):
         return State.array([env.state for env in self._envs])
 
@@ -142,9 +119,27 @@ class ParallelEnvExperiment(Experiment):
             device=self._envs[0].device
         )
 
+    def _run_test_episode(self, test_agent, env):
+        # initialize the episode
+        state = env.reset()
+        action = test_agent.act(state)
+        returns = 0
+
+        # loop until the episode is finished
+        while not state.done:
+            if self._render:
+                env.render()
+            state = env.step(action)
+            action = test_agent.act(state)
+            returns += state.reward
+
+        return returns
+
     def _fps(self, i):
         end_time = timer()
         return (self._frame - self._episode_start_frames[i]) / (end_time - self._episode_start_times[i])
 
-    def _make_writer(self, logdir, agent_name, env_name, write_loss):
+    def _make_writer(self, logdir, agent_name, env_name, write_loss, writer):
+        if writer == "comet":
+            return CometWriter(self, agent_name, env_name, loss=write_loss, logdir=logdir)
         return ExperimentWriter(self, agent_name, env_name, loss=write_loss, logdir=logdir)
