@@ -5,6 +5,7 @@ from all.core import State
 from all.optim import Schedulable
 from .segment_tree import SumSegmentTree, MinSegmentTree
 
+
 class ReplayBuffer(ABC):
     @abstractmethod
     def store(self, state, action, reward, next_state):
@@ -22,14 +23,19 @@ class ReplayBuffer(ABC):
 # Adapted from:
 # https://github.com/Shmuma/ptan/blob/master/ptan/experience.py
 class ExperienceReplayBuffer(ReplayBuffer):
-    def __init__(self, size, device=torch.device('cpu')):
+    def __init__(self, size, device='cpu', store_device=None):
         self.buffer = []
         self.capacity = int(size)
         self.pos = 0
-        self.device = device
+        self.device = torch.device(device)
+        if store_device is None:
+            store_device = self.device
+        self.store_device = torch.device(store_device)
 
     def store(self, state, action, next_state):
         if state is not None and not state.done:
+            state = state.to(self.store_device)
+            next_state = next_state.to(self.store_device)
             self._add((state, action, next_state))
 
     def sample(self, batch_size):
@@ -48,12 +54,12 @@ class ExperienceReplayBuffer(ReplayBuffer):
         self.pos = (self.pos + 1) % self.capacity
 
     def _reshape(self, minibatch, weights):
-        states = State.array([sample[0] for sample in minibatch])
+        states = State.array([sample[0] for sample in minibatch]).to(self.device)
         if torch.is_tensor(minibatch[0][1]):
-            actions = torch.stack([sample[1] for sample in minibatch])
+            actions = torch.stack([sample[1] for sample in minibatch]).to(self.device)
         else:
             actions = torch.tensor([sample[1] for sample in minibatch], device=self.device)
-        next_states = State.array([sample[2] for sample in minibatch])
+        next_states = State.array([sample[2] for sample in minibatch]).to(self.device)
         return (states, actions, next_states.reward, next_states, weights)
 
     def __len__(self):
@@ -62,6 +68,7 @@ class ExperienceReplayBuffer(ReplayBuffer):
     def __iter__(self):
         return iter(self.buffer)
 
+
 class PrioritizedReplayBuffer(ExperienceReplayBuffer, Schedulable):
     def __init__(
             self,
@@ -69,9 +76,10 @@ class PrioritizedReplayBuffer(ExperienceReplayBuffer, Schedulable):
             alpha=0.6,
             beta=0.4,
             epsilon=1e-5,
-            device=torch.device('cpu')
+            device=torch.device('cpu'),
+            store_device=None
     ):
-        super().__init__(buffer_size, device=device)
+        super().__init__(buffer_size, device=device, store_device=store_device)
 
         assert alpha >= 0
         self._alpha = alpha
@@ -140,8 +148,10 @@ class PrioritizedReplayBuffer(ExperienceReplayBuffer, Schedulable):
             res.append(idx)
         return res
 
+
 class NStepReplayBuffer(ReplayBuffer):
     '''Converts any ReplayBuffer into an NStepReplayBuffer'''
+
     def __init__(
             self,
             steps,
@@ -177,7 +187,7 @@ class NStepReplayBuffer(ReplayBuffer):
 
     def _store_next(self, next_state):
         self.buffer.store(self._states[0], self._actions[0], next_state.update('reward', self._reward))
-        self._reward = self._reward -  self._rewards[0]
+        self._reward = self._reward - self._rewards[0]
         self._reward *= self.discount_factor ** -1
         del self._states[0]
         del self._actions[0]
